
# q-expansion of newform 25.16.a.f, downloaded from the LMFDB on 15 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 25
weight = 16
poly_data = [-65015354624, 0, 153469728, 0, -29397, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0], 1], [[0, 2, 0, 0, 0, 0], 1], [[0, 1648953712, 0, -368353, 0, 13], 4805184], [[0, -11605603568, 0, 200897, 0, 19], 2402592], [[-39196, 0, 4, 0, 0, 0], 1], [[53082976, 0, -24373, 0, 1, 0], 174]]

hecke_ring_character_values = None
aps_data = [[0, 1, 0, 0, 0, 0], [0, -2, -1, 0, 0, 0], [0, 0, 0, 0, 0, 0], [0, -2842, 105, -7, 0, 0], [-18098348, 0, 0, 0, -840, -158], [0, -353236, 24492, -169, 0, 0], [0, 456688, 450156, 4962, 0, 0], [605165940, 0, 0, 0, 108664, -114], [0, -99028294, -1020069, 28605, 0, 0], [-47694744790, 0, 0, 0, -1309584, -309028], [-46039458048, 0, 0, 0, 968480, 368196], [0, 1479916284, 123302064, 334773, 0, 0], [-1025546480398, 0, 0, 0, 14834280, 3323051], [0, 2515243414, 155402103, -8714030, 0, 0], [0, 1413166750, -537307379, 3142765, 0, 0], [0, -19196066380, 939963876, 28284681, 0, 0], [-2483876387780, 0, 0, 0, 29687592, 9340090], [-1892010238098, 0, 0, 0, 61060400, 46984695], [0, 141013485778, -184139499, -17049998, 0, 0], [21948857634552, 0, 0, 0, -1449334800, -256385640], [0, 372643146600, 4137273300, -145392048, 0, 0], [4346975656560, 0, 0, 0, 1908421696, -752623884], [0, -257940806530, 8901274707, -180440850, 0, 0], [-9878281784970, 0, 0, 0, -11234024112, 405494676], [0, 3142987034528, -148479622116, 3264329294, 0, 0], [-609858545528498, 0, 0, 0, -11386600080, 1585978444], [0, 2491735867466, -280439609133, -2466253291, 0, 0], [0, 4959942217114, -195217367819, -3806727524, 0, 0], [-934727229350430, 0, 0, 0, 4154566912, -1093501083], [0, 9577459120304, -341948338048, 4092247556, 0, 0], [0, -22476727354818, -486240753159, -13323328257, 0, 0], [1636232456151452, 0, 0, 0, -106334807640, 3890620802], [0, 3467723387416, -1204062339024, 37953841434, 0, 0], [1423574903390380, 0, 0, 0, -185092390392, 49909089198], [-11832788164632950, 0, 0, 0, -49090969680, -78569851667], [2161258481391752, 0, 0, 0, -193845985680, -38882266716], [0, -94179899557340, 3298446931392, 71977984459, 0, 0], [0, -15348861279042, -4446600117369, 163516020108, 0, 0], [0, -153291352783274, -8423002178811, -220504034889, 0, 0], [0, -162887007684628, -7732779012288, 45138905073, 0, 0], [-62676440938633740, 0, 0, 0, -281228605704, 128925697242], [-62799795881615298, 0, 0, 0, -862068252400, 199206834420], [-64413942093275648, 0, 0, 0, 2378527225920, -123065863976], [0, -112296128836288, 1956391227036, -361202486266, 0, 0], [0, 694229788855420, 31011550241556, -180244576665, 0, 0], [-78122609674916600, 0, 0, 0, 2042298585360, -86074103016], [156627120951008652, 0, 0, 0, -992021940280, 684966592554], [0, -1433588972241470, 15264691255935, -441200689163, 0, 0], [0, 1523004414529858, -16102712986263, 396680350236, 0, 0], [85106276914034610, 0, 0, 0, 1740356791696, 1538189509380], [0, 501232387977608, 168022443056180, 1813620647384, 0, 0], [-326634402390519920, 0, 0, 0, -2425574841792, -287912484476], [-403356753340153398, 0, 0, 0, 1028916139400, -3332515465545], [-415234037915054748, 0, 0, 0, -2801934791400, 2856909467490], [0, 1913945823901504, 7876678074336, 628932124656, 0, 0], [0, 1219472767084538, 25545678563231, -4579737708997, 0, 0], [34158903268806690, 0, 0, 0, 57197119560144, 1427746426257], [-456469064741774448, 0, 0, 0, 21390808926080, -2522625640284], [0, -6616178504291764, 482706095235600, -3566582123935, 0, 0], [8088962200455202, 0, 0, 0, -46024357822920, 2852387504551], [0, -9217166273161642, 11386647540915, -2034987833476, 0, 0], [0, -13151870501515132, -364487901260328, -3761495201793, 0, 0], [0, -4881579726089214, -1386482703167307, -14051712995778, 0, 0], [1959259716711330152, 0, 0, 0, 180174115856880, -16416510928684], [0, 19029766126355032, -50379075549600, 1753669912450, 0, 0], [0, -3181809692019164, -812627299184436, 1049260318401, 0, 0], [-536338417902569548, 0, 0, 0, -168114463514760, 1283246793798], [0, 37010437480231984, 2197235536246344, 3070702300168, 0, 0], [0, 7271584429278202, 878452115700673, 6548420097766, 0, 0], [6429722165549313450, 0, 0, 0, 76514779156240, 16358802251124], [0, -40920123624538912, -527801121463816, -12651217540300, 0, 0], [-9631711719281362680, 0, 0, 0, 241978846114992, -775462779132], [0, 46519782128776142, -2798593160682015, -61570733962561, 0, 0], [0, 54521563541475860, -3531370815233280, -23674089671953, 0, 0], [8529496591268181660, 0, 0, 0, -419136973033304, 50201761136814], [0, 33909860395750274, 4596189629551911, -19418371706223, 0, 0], [-26821112376715036870, 0, 0, 0, -25038693483792, -76604140698187], [0, 71722700315510676, 241323249612492, -94343127583467, 0, 0], [7203320028810066002, 0, 0, 0, -325030804757040, 17171054859572], [23586555892347692670, 0, 0, 0, 321050501749432, 117364851753669], [-52833840606753471260, 0, 0, 0, 248938966212504, -39439527226982], [8362370522942899302, 0, 0, 0, -269592853154320, -102166107707469], [-30070637694210204048, 0, 0, 0, 843536257503360, 50829533103252], [0, -63126246530262480, 6803801591196252, 256898723457930, 0, 0], [-20948945232606428520, 0, 0, 0, -1055010494611952, -24148588932516], [0, -278766153531024874, 9773211126197115, -253051125307224, 0, 0], [-81727770093669809850, 0, 0, 0, 183202260151800, 186192207468657], [0, -266379344679826216, -9479683697861064, 252863060141726, 0, 0], [-68477817651136035098, 0, 0, 0, 613649790079920, -74052214152356], [0, 334268731930608002, 21424537019058675, -240874232036245, 0, 0], [0, 363357928472267314, -11791109833243863, 498176844004920, 0, 0], [-83350426733395812640, 0, 0, 0, 2596631209209216, 245341051996064], [0, -619447536811769946, -6627301775845071, 284575399815813, 0, 0], [-50659053251812047148, 0, 0, 0, 1486053636462840, -110152233997762], [-14279250844690783500, 0, 0, 0, -3469594450960520, -439000407484494], [0, 22433029884815834, -8837735619864405, 958335137035533, 0, 0], [-6049246143964016630, 0, 0, 0, 3882616883575152, -178333855950116], [151985172022234607802, 0, 0, 0, 2851970971826880, -455351897893344], [0, 507707956354405926, -42447680833514349, -633615840830160, 0, 0], [194083269302744486102, 0, 0, 0, 4549429561617360, -25166720301948], [0, 1493844579707034530, -97849403474810799, 147923115038480, 0, 0], [0, -82223316188696876, -13287344216987264, 1335567678287311, 0, 0], [0, 463823574020172686, -94971880294300081, -813452730163588, 0, 0], [43890413981115973790, 0, 0, 0, 3477067760072184, -2075945323899307], [-128207363784934977948, 0, 0, 0, 13236055129865240, 1435454611123338], [0, 1033950986624303808, 31354302037645272, 1067200056276876, 0, 0], [0, -3429965211975373238, -79172463050118423, 724967939976102, 0, 0], [0, -3529083484178411440, 2332877320060944, 1794347344959348, 0, 0], [298658008235215322200, 0, 0, 0, -3522331319937360, 2699277204452704], [427361919141863716002, 0, 0, 0, 1000880587439000, 608472409189935], [0, -1664981942918466962, -70577273998823355, -1249273757919227, 0, 0], [0, 3756142060186781796, 17603770944435564, -2570992576940943, 0, 0], [0, -1549123022533833800, 67851524166875748, -795137558355612, 0, 0], [-151055585719109979860, 0, 0, 0, 15698010637932744, -3233418713396142], [-325705599672081897048, 0, 0, 0, -25521814540275280, -136525628051676], [1222781469914648492602, 0, 0, 0, 5147639630799720, -340647527730521], [0, -1153428817297596658, 260082348970040931, -4669182723670966, 0, 0], [0, -2239303250749931738, -46734527226312087, -6140941925430759, 0, 0], [0, -689231713567950292, 381158401685124564, 3614227695778875, 0, 0], [-259138912580693817580, 0, 0, 0, -30460606755606408, -5288207616628414], [758099652012942570902, 0, 0, 0, 18313025184394080, 508858524277071], [0, 4554097374528503200, 118047552338029620, -1410358050181718, 0, 0], [0, 1856922183776958172, -240126824971687364, 4842307787699683, 0, 0], [0, -7318319784268872394, -415155668527456977, -1291807765876962, 0, 0], [-2312708039390068064148, 0, 0, 0, -26415278584682680, 4729676862657474], [772861715644742831502, 0, 0, 0, 33915967551578880, -4300496045368029], [-363514177217103693230, 0, 0, 0, 43270730208725232, 8256083583360972], [862605651389807625840, 0, 0, 0, -9041874368310336, 8066766469575588], [0, 9062695367702908406, 546390942570283065, -4918378438820395, 0, 0], [0, 12467208587351177372, -311052660843531816, 11172426766806401, 0, 0], [-2854457262298312443420, 0, 0, 0, -63506888122213352, 6780286470002802], [0, -2554357964049380230, 421189953866787959, 384777032313023, 0, 0], [-1750548739184512123248, 0, 0, 0, 7647262226874080, -9671849476881504], [0, -6284216780873911764, -128147953125662712, -3840912977455323, 0, 0], [2366581108848993455402, 0, 0, 0, -39835851281840880, -7478573369663836], [2270892431892601640190, 0, 0, 0, 36129769262369344, 6632297241517152], [0, -15308719927479807292, -247326293625557772, 2229635825360061, 0, 0], [0, -24634072697259177470, 77657519859574845, 8211368787914986, 0, 0], [0, 12638919380489735236, 165427233935471892, 25175327630072973, 0, 0], [3782897590576283866470, 0, 0, 0, -86337438359454528, 11324085987535296], [-4742759610353125630348, 0, 0, 0, -29118064829681160, 16824699294077898], [5350878481679269877302, 0, 0, 0, -120798760169321280, 18009790488796519], [0, 22359054577296278522, -940052898721328733, 7372304722721993, 0, 0], [0, -7068456463746556742, 1196763284438130297, -43192448502913974, 0, 0], [2599087759673261425810, 0, 0, 0, -117986465438212464, -4569894781251831], [-2827136233773159901720, 0, 0, 0, 192677842184223408, -12204085675395100], [0, 16968484579773544852, 1247951439634307988, -393400269232583, 0, 0], [0, -12947843238332125304, -2158967033018824392, 30524284659413922, 0, 0], [3502827450905176649820, 0, 0, 0, 147553924604157352, 18458023734787770], [0, -38587082644616429134, 1952574275914809459, 13083433610953767, 0, 0], [0, -15269500956299020076, 2795189050525557528, 3428437929335419, 0, 0], [3048478477814027492202, 0, 0, 0, 318788404214079480, -23657474414305629], [0, 46530622964215328238, 2084809007457286215, 28931644682831544, 0, 0], [0, 22255101679093682038, 2016962057581271793, -2735877337519575, 0, 0], [0, 93633685889733922682, -241040437329405291, -15790188384354700, 0, 0], [-2554797332194879452848, 0, 0, 0, 182278758640325760, 65187090571245772], [10006000344711462169240, 0, 0, 0, -631244126305789776, -17474807790857088], [-420864316837934358490, 0, 0, 0, 393422659115421816, -74412823881263599], [0, 137163391316552834040, 3501879205526008620, -54067524592980024, 0, 0], [2013988262226097964102, 0, 0, 0, 151373376931343760, 3434911326312692], [0, -99786023835343884446, -713114034658348995, 790138073362962, 0, 0], [0, 22526400138030420440, -1509221862931454824, 49764197954177486, 0, 0], [0, 119969800129413442486, -2306676942685695771, 37430671647193711, 0, 0], [-6930837804132188679948, 0, 0, 0, 463309581618498360, -46804263434108418], [0, -20891118132926442704, 4128151579870769380, 44819259737254750, 0, 0], [0, -125220200080556004214, 1379064865871561463, -22922366645009757, 0, 0], [-8126230267863845607648, 0, 0, 0, -179227757811186880, 151140200005556544], [0, -154549883350084658980, 6447785609057514636, -22554111925835845, 0, 0], [-7264552647950071034130, 0, 0, 0, -631198893417094208, -7277046266971968], [0, -62219375273113040332, 3292323646223205036, 83463114965326893, 0, 0], [-13777988306504818057060, 0, 0, 0, -539948565584872536, 24975064227431006], [7914635889882884149302, 0, 0, 0, 48939269576438960, 24896689406410332], [-28099194645761496643048, 0, 0, 0, -943823994323191920, 25440913899892916], [0, 161583716592122927656, -10287859122711613332, -12003643254382532, 0, 0], [-32248144117394115262320, 0, 0, 0, -445685193925167392, -120635319686221248], [-54079581104506527636650, 0, 0, 0, 294628527384651840, 68994496683220096], [43286730655803201405252, 0, 0, 0, 488001838272755480, -6372491671919454], [-30600700225696305898098, 0, 0, 0, 112723470080593200, 155140088184204780], [0, -106248730832859032886, -434286003165744573, -202931065710216579, 0, 0], [28982613465238765928290, 0, 0, 0, 993568386655111584, -148345289038290867], [0, 43238202882832535006, 1577747461607634561, 305585023338061859, 0, 0], [-24971814997616845474148, 0, 0, 0, -154351100852763480, -319574923535869766], [0, 107395946000039117636, 4921928925432127980, 119320083024335801, 0, 0], [0, 20229705060696916312, -10277027354438468492, 415469787923006596, 0, 0], [0, 4802161669184910818, 3560182362900021339, -126161179291163985, 0, 0], [-22507742891969748414430, 0, 0, 0, -719139745902150768, -38129817579798604], [0, 32814034987925650980, -4690858291579096272, -107679671826130797, 0, 0], [0, -46456795237841081042, 16771592921499569523, 232927564885118266, 0, 0], [15044783582012648864910, 0, 0, 0, -2616282720034796744, 72902911483370541], [54435200380783779082752, 0, 0, 0, 273555547798785600, 71052034579350960], [0, 50090806967611636800, -5423868135411432024, -131151825722098524, 0, 0], [0, 266577022694460549542, 2359696347505997955, 119099418951077160, 0, 0], [51535366573445156711052, 0, 0, 0, -845520004928937400, -169815384979692510], [-98055163380104292577298, 0, 0, 0, 279812037744801120, -30555662711193701], [0, 308809677947948768626, 10030011212661059541, -247499963281468566, 0, 0], [0, -187701573775861346296, -647010886009613652, -274989269543603340, 0, 0], [1816979397890113921002, 0, 0, 0, -520663137720158440, -143664548011330293], [0, -397738144288304066468, -20806962928035402420, 262644225035414395, 0, 0], [0, -47848218322147656320, -19288902680612532512, -242054069031897632, 0, 0], [0, -77629110865118655862, 33737945199933478523, -73257303215051839, 0, 0], [57332250667466653347610, 0, 0, 0, -3132214176157012464, -517194446580523292], [112519088807275320259952, 0, 0, 0, 1205642479541526240, 85587270845085528], [0, -775786851383639988308, -26803503014964193428, -23742142772486873, 0, 0], [-40520017045284438797250, 0, 0, 0, 3399752503642252240, 484179333941261988], [107089143673118763448620, 0, 0, 0, 79938267621201672, -439262484139959582], [0, -435974140302645889148, 18283230348344178376, 596428259034381463, 0, 0], [84637807267790031868960, 0, 0, 0, 2554448087802619296, -532288293159447612], [0, 367314787546832578862, -31211558692227517941, -62879151678588114, 0, 0], [20466050911140257551430, 0, 0, 0, -5407797825599683392, 545525688634067552], [136904067618918577628852, 0, 0, 0, 1660772685860734200, 587822453886845310], [0, -368003563579099773072, -2485597478815335996, -1292340681533096226, 0, 0], [-66990055625686346863498, 0, 0, 0, -6468506244859192560, -68242717573742557], [0, -514807622783193057014, -11111590039424140473, -1098311798122816421, 0, 0], [0, -697982453539889316806, 14189110182652736881, 352857306937917646, 0, 0], [175261959883287622464040, 0, 0, 0, -1773220085109359856, -49267322338169840], [-150280887032103659205198, 0, 0, 0, -2787217916695348600, -1111731958789940205], [0, 340744391185087561390, -2783584826529682551, -983735458356351053, 0, 0], [-432584758512561101455598, 0, 0, 0, 493498064727448080, 294817542215915236], [0, -980861876299133484698, -66911992801450349955, -409496420796040881, 0, 0], [0, 1544807419142384076092, 15010107112017337572, -1265582893383461457, 0, 0], [-181851852848552079018298, 0, 0, 0, 3358072826672536320, -481417309848835281], [-311842604395561693324200, 0, 0, 0, -4961127164691169520, 753159962753240220], [-63094259839031083487330, 0, 0, 0, 6197277514386875952, -683312773832962292], [0, 1159112510384951969970, -116515802238722851785, 973610715461781717, 0, 0], [0, 1650940434558364565314, -48811803255522124227, 356029015151642634, 0, 0], [222233542829259068516010, 0, 0, 0, 655175350170283456, 1564833578617732809], [0, -1444625417942096040712, 51924044124877790700, -1208448767820308616, 0, 0], [-109923217732652944931520, 0, 0, 0, 11862597220272631968, 1264242200731327188], [0, 697473420796250189846, -99446401773588643083, -1331286988516241137, 0, 0], [47282118705335631919252, 0, 0, 0, 5971884022659882360, -2234220493353606098], [0, -730374855601842354868, -98556619152671666412, 575446559972483987, 0, 0], [-159317655786977459995980, 0, 0, 0, -3635605174435478408, -2625035799506252046], [325762546590687566807552, 0, 0, 0, -8987682273178658880, 312626128185879864], [-311142674019279531502798, 0, 0, 0, -2115518189004146760, 65614459663543583], [0, -2503060641146275238090, 105468624690437292327, -1024732573911361310, 0, 0], [0, -1891494386955686954258, 183016835882023934097, -433103271558137073, 0, 0], [-50077881411700825264170, 0, 0, 0, -14323729078987961192, -189323543953364271], [0, -1985414242394421287212, -153613966467128394468, 468598684543086477, 0, 0], [-49758084893501600310500, 0, 0, 0, 15291273960821428200, 1464839651259909250], [-879510968501105005483848, 0, 0, 0, -1375026536641904880, -1360623015636124476], [0, 290738913357057657662, 64749218727945950747, 1194134633173179098, 0, 0], [183274875101393479036452, 0, 0, 0, 11455858785690360920, 1977962834917525914], [0, -2664732256424705082502, -9779103126734880273, -3200049605190086653, 0, 0], [515379833292351404885850, 0, 0, 0, 23526157178325458320, -974853854371588668], [0, 4833869459410515312848, 78591365222934712184, -1123252126080915160, 0, 0], [-517047690602953776990280, 0, 0, 0, -12719003510237267568, 126363178490414228], [0, -2309350875978608587938, -109473419505514250775, 3165811150893062079, 0, 0], [-624825137153757123550948, 0, 0, 0, 8985194863300623720, 1444567281896972534], [-55852192396628854369940, 0, 0, 0, -3212386039359732984, -4484350650321717630], [0, 219594984884321573378, 262546245044081332395, 1002157449431507199, 0, 0], [0, -3605063242295020400540, 83600087202673499436, -1005111286037630735, 0, 0], [-114226505144704140979998, 0, 0, 0, 13237764082816162800, -1676522620804582260], [0, 2228187272905596429382, 225064584541683625329, -908772116083531395, 0, 0], [512283990303928227269070, 0, 0, 0, -4476579299985731768, 2243971269079876401], [0, -5779471483093441438708, -76548960788910427080, 346273442490671445, 0, 0], [50823565591723101817140, 0, 0, 0, -4371907804530198216, 1693587917755670046], [865082111888291326798302, 0, 0, 0, -1548049122171255760, -2092574689898882772], [0, -1239385062647982711526, 284151098134842446553, 2852635755377198594, 0, 0], [0, -1134009814577029379588, 12551460823716906432, -7724182235224088403, 0, 0], [0, 3746335047334109211432, 31053432910180215384, 2746520557551680250, 0, 0], [0, -4673386584257396770862, 32270248442610838611, -4594079058437292977, 0, 0], [0, -93859761342775228478, -235108532089590306255, 3947947192394529624, 0, 0], [688073339912172262913490, 0, 0, 0, -797147817677619056, 3062413756508794356], [0, 5159991372275565866268, -339080116323858665448, -281406070880063823, 0, 0], [0, 5881427859570666916000, -114754549381901974764, -2342790465031051350, 0, 0], [1000073310190415246428900, 0, 0, 0, -34313082989211856680, 1978179838636256346], [61704461637760960843770, 0, 0, 0, 281727728631961872, 1467088399607166180], [-657908077187364418430198, 0, 0, 0, 67785190739646603840, 4538931925686036448], [0, 3712683838052072956118, 359676722690732875803, 2990461894135561976, 0, 0], [0, 5714951582683417202660, -466391177002151569648, -4484099911277625085, 0, 0], [1315445536070092034808102, 0, 0, 0, 30723097355665764560, 4418550375873935412], [0, 1617651049278678972018, 148797147882883268889, 4795256333375451024, 0, 0], [0, -1159759714566920262536, -235107966423672852300, -8206917932579837252, 0, 0], [-785217465304889376386880, 0, 0, 0, -3318230571709964768, -3793475086211614980], [0, -5434832436148460446832, -172451266442204700648, -4789340872118038664, 0, 0], [0, -1889905328560738406454, -318324862090727537217, -7319396591562737937, 0, 0], [0, 2194571219093373785674, -322658701810470617571, -8731187385162147132, 0, 0], [-951652419276405498902070, 0, 0, 0, -56124615711533883632, -4557912875579235996], [291846350543679110518002, 0, 0, 0, -61717525666816291720, -2278344659498658849], [-433239213067071914171348, 0, 0, 0, -43550369788336332600, -392953199413756490], [0, 11642718765619247631698, 459784329143199672203, -3632357280329032429, 0, 0], [344582870261867130836952, 0, 0, 0, 57606559629702490160, 5897854898667994512], [0, -11950527682724374690682, 199327968052621274349, 6518504672096700639, 0, 0], [2549137107193514204449902, 0, 0, 0, -5299884208845272080, -3725875295357900436], [0, -6282102707666748003350, -58926693348054597327, -17438947319466121862, 0, 0], [-3126282782913211062458448, 0, 0, 0, -40654403626319058720, -11725034518952027184], [0, 3945728169316039235472, 611150855405031807852, 7962429440413840458, 0, 0], [0, -12953973663446690313812, 880407415131806882332, -2784064221290615489, 0, 0], [-2471110402671541615932840, 0, 0, 0, 10631302202721087856, 9232580726904923616], [661515805626182688354630, 0, 0, 0, -52128138298556190072, 17221831911004660437], [-1590353816671869896714498, 0, 0, 0, -111177151975332612240, 13183687248445436767], [0, 8576764911922749092482, -806810805107652257691, -2648064547984913850, 0, 0], [0, -5367077300039680712680, 422946215525092971788, -9624732782348742256, 0, 0], [-2480944996347267149249548, 0, 0, 0, -104110219160108909640, 11997945277387044662], [0, -8909604642083206955636, -657509600141245922664, 117733454968597237, 0, 0], [1059662279388064766753650, 0, 0, 0, -2330907234814573680, -19513986363649120199], [-3813906590683167486121248, 0, 0, 0, 16544738119000198400, -2013124495748934960], [0, -5304982735049508179692, 24267630949648936568, 15627247463526459371, 0, 0], [1478396414756856596308860, 0, 0, 0, -107638307314085065944, -9911754583879130478], [0, -689906192882683911358, 804742628772884555697, -11137701480099207448, 0, 0], [0, 16403754512652218895464, 328220834719631932368, -9987942615166548970, 0, 0], [0, 26176343540105000192308, -732585024891732643296, -7589427846565559481, 0, 0], [-831566682145643221190000, 0, 0, 0, -76723213991038126560, 4293564490001915208], [0, 30041597451945194198174, 645369851866087225035, -11493360962717546022, 0, 0], [2339688158134152150731652, 0, 0, 0, -51162657509788926760, -21248881114312680702], [0, -23324300880814915378848, -1500194799440756009340, -2730054073831116846, 0, 0], [0, -15570519950662563501254, -63068679771077980115, 3901498779078746920, 0, 0], [-4687464477837739965134790, 0, 0, 0, 99145535997229711696, 1896622161838050468], [6237085393765332616214680, 0, 0, 0, 2935749316694214288, -2628987241881440012], [0, 22957728857543727052644, -484804501441540744560, 26211322197986012403, 0, 0], [0, -16217380145835644712718, -148717616232925996425, 8610611238910749525, 0, 0], [487013383637563659880290, 0, 0, 0, 128366289633233337744, 25972174081535266980], [-689899030851784606400798, 0, 0, 0, -114711013824496092480, -34598308723889785856], [0, -28259600387288234016130, 814702014443076660807, 5889888600116069900, 0, 0], [0, -23790770970854583589898, 1778910069599477049117, -19045367877450487053, 0, 0], [28019075340558439785030, 0, 0, 0, -154463214546832840112, -21420761087093495724], [3475882562284282534519700, 0, 0, 0, 91118710488576533880, 525443037486875822], [5114897015955012429981152, 0, 0, 0, 127005041730260992800, 5985826048860839780], [0, -14484194869539437437568, -1624420825790980001040, -18630081620487904760, 0, 0], [1003027671833982326793910, 0, 0, 0, -189603612990146539224, 1442053882435033525], [5978806080038279757805452, 0, 0, 0, 59865419950053193160, 18903899359766486682], [0, -8010382209197844395192, -683454669965076128112, 37528797469220990110, 0, 0], [-3936558647197990067318898, 0, 0, 0, 129752628226632991440, 8685639096892784463], [0, 19993367409250541149746, -907039926651593338125, 25002171497241004071, 0, 0], [0, -33476766080900603205496, -1814740566263343764280, -4379310588650931462, 0, 0], [1425563573206798869107402, 0, 0, 0, -222852418130185422840, 17847738265160267847], [9408546211013405406112260, 0, 0, 0, -90575904964813359464, 8462817605214313890], [0, -13757898350508599382026, -526194170198843918325, 5850159096581419288, 0, 0], [0, -36239463098056566396434, 73379389363128738613, -37946333582322040403, 0, 0], [0, -11229976702490444165404, 892903274556376445484, 16163372970853526337, 0, 0], [-3248189933421768734477698, 0, 0, 0, 188790791072270574480, 40547432227170061671], [0, -15397614619493667947516, -27495750312786363416, 70583702656333225303, 0, 0], [-10322215232188550797305920, 0, 0, 0, 113851157839971774528, 32773781954279549568], [0, -76784799067944734092498, 1443580455792000825611, 11112097465481836094, 0, 0], [7715694319369046449067252, 0, 0, 0, 348108423028184022840, -22053393321219299682], [0, -32782282139121729982070, -492809797882749120107, -2019082082293841912, 0, 0], [-1193359703250889388459310, 0, 0, 0, -421938883108286574176, -22366005387643222347], [0, 93567769327112354319584, -3011987237743172913336, 10002145943572089564, 0, 0], [-7239950630399201940586798, 0, 0, 0, 190834874591883302040, 14162579868499456263], [0, -15465828815468527569090, 1320597128127482899125, -77420890976100133599, 0, 0], [0, -3866215615885309884908, 4184991418970888848536, 48904670610852659179, 0, 0], [0, 87959483674265580678568, -429925871728190802456, 27778856741536000194, 0, 0], [-22087664784021959461037030, 0, 0, 0, 214903786001444780832, -7423060854710599607], [7985317995441256327624152, 0, 0, 0, 321185543707246369040, -67449364574125954452], [0, -32700923790740444993956, -2996911687385025869104, 14696844268816683197, 0, 0], [2338744729696632916311780, 0, 0, 0, 86006720668137070488, -85943480709341264214], [2494617023932508522976102, 0, 0, 0, -454746184946035766800, 50910358869556191555], [0, 91038049388095579691690, -3553357807356942257559, -17836203201648524770, 0, 0], [-3135496563656113706211248, 0, 0, 0, 172270778589826032480, -36805953637602106784], [0, 7779775256609491108492, 3145553478364419380964, 7910680033758946635, 0, 0], [6406816168953448621141052, 0, 0, 0, -187544587518895263960, 14341580341379560158], [0, 57380960531001716569176, -196642256213321515200, 93214789142859433650, 0, 0], [-6586767014273136213111298, 0, 0, 0, -101103164338169946720, 20032288438697790851], [0, -15588826326560877677486, 4708674476224753635951, 27432983334215598097, 0, 0], [5991450169620346273452130, 0, 0, 0, -40283174575138011792, 29647558380264355308], [0, 31352088227860247018360, -1998850385111042460396, 38046933640410869388, 0, 0], [-13398083569936146421179200, 0, 0, 0, 440538322215667927200, -25508920652734539476], [3085694239609601350205652, 0, 0, 0, 511360982954260815480, 16887219672732676206], [0, -62269067548961766653744, 470110908668605693444, 7121075830313901526, 0, 0], [0, -8455002313333759135510, 3375268484249781565335, 81498162484850607627, 0, 0], [0, -50451834443360235501124, 204541891006410653916, -137260290987057401941, 0, 0], [-6014266833427748125407398, 0, 0, 0, 725932568644230682800, -3426628711839514100], [0, 32855248078591854872974, -3609100377999687867575, -23108500133074850453, 0, 0], [24253093681383915606009020, 0, 0, 0, 236098919849476142952, -22511093615202069394], [0, -123440922875528270159790, 3751328480767417879293, 18400414792209365358, 0, 0], [0, 23264886898615139509000, -6444571122940759042020, -102622284692624608628, 0, 0], [0, -22552029543514095148172, -1383485365626142963068, -45944658506650221879, 0, 0], [0, 144663411281666641276026, 209696629485785519007, 22806425708542459659, 0, 0], [15121095977748212549524802, 0, 0, 0, -584403440616651897720, -71937769892701813029], [22408943632252488402599452, 0, 0, 0, -434285727471619013400, 55161140205900907630], [31404153155925996381903180, 0, 0, 0, 217550930523259875208, -26516988955148589738], [0, -41418680507486550827614, 2241505832700819849795, -203138672104367890389, 0, 0], [21057261974214071902723850, 0, 0, 0, 757108750868339635200, -36280650897798517687], [-16488165632568257599468248, 0, 0, 0, -570778947162196809040, -189527459898963079548], [0, -31163358883104686825244, -816885571665812305812, 140003562836739933057, 0, 0], [34810930917127691330227060, 0, 0, 0, -939498370228476508104, -59078205599031681554], [19242392837122757137856352, 0, 0, 0, 481796169318190417920, 58094264126645513904], [0, -145831804002615430505952, -3998221314291842393088, 188301547531099373112, 0, 0], [37099284356563796549702070, 0, 0, 0, -48769458791527985448, -4149602509114608735], [0, -84733167241312900649752, 2250190501438508974776, -57261448574897953318, 0, 0], [36284232007540030327973302, 0, 0, 0, -247589814651892841520, 62512869234612873796], [0, -57199638996260391965848, -5856030313923230040456, -130134788763232713414, 0, 0], [0, 92818353169582083230982, 11549114910499709927733, 84445028275073152251, 0, 0], [0, 274759348779886445389024, 7873979622018138793296, -136276073863637829024, 0, 0], [-1874166922073600966671580, 0, 0, 0, 1500197086417818478872, 82595419391660068362], [0, -42928165288195014703414, 3055819414998156815939, 61117354583726651117, 0, 0], [-35407596174701724466262448, 0, 0, 0, -234272514150529228000, 113626012846236500040], [0, -236876114317921474048340, 2102824137324294873504, 86724175951612099297, 0, 0], [0, 14864837078488261136694, 7933389965096525077491, 104545765159870432452, 0, 0], [0, 212564598235552237319278, 2468336570595810088813, -122564622035539802735, 0, 0], [-18964381149535866134559770, 0, 0, 0, -69038180884901690232, 20831350049846847813], [0, 338825032428842542464164, -631745376554824324992, -146331290132894465685, 0, 0], [26697657742663897681353900, 0, 0, 0, 876022530437068256520, 181385473874451928686], [0, 49912816168389690418898, 6976509960415442051265, -263946199246829255932, 0, 0], [-33024084750163499528949848, 0, 0, 0, -554061678341829799920, 121190878746799095976], [0, -150688032541353651372040, -9822011990608576062912, -159204897808596703846, 0, 0], [-32086369414585122475304160, 0, 0, 0, 670568962753416508864, 83333188288918457328], [2183248510928912357547110, 0, 0, 0, -1179934177539827984064, -65430887396315382352], [-52113655162147097046577548, 0, 0, 0, 141777418809912526520, -35078915680237362726], [11032389310926284778446102, 0, 0, 0, -376318892402671705680, -110987247606570705541], [-42352035987941228019032750, 0, 0, 0, 54071584267691109360, 27549301229589832257], [0, -30754670494828889629696, 10103831055798678052340, 273526401116814743618, 0, 0], [0, 45907064276834238523822, -2664589175768947049295, 173046968385450350239, 0, 0], [0, -266205422679088353691448, -12128460442254985140224, 205310086086721497238, 0, 0], [33733259927476936862883930, 0, 0, 0, 119662677781010425488, 383179852716490058493], [14331033383825888227019352, 0, 0, 0, 45452071272120186800, 376996068524606856120], [0, -29727318890291993371852, -4143256449912451823676, 155009923767873796409, 0, 0], [112673777648324995835462002, 0, 0, 0, -35223746780790512880, 23010789759303432484], [0, 45394534046954048827934, 5764788381578407186755, -211870572115505501602, 0, 0], [85741095914168769703157540, 0, 0, 0, 79136908079108392344, -41073562368977032570], [0, 335349868613747689677328, 4936507724679247622520, -52998423587748916376, 0, 0], [0, 13774578428720668878220, 3834173320025303381040, -10056813015034862799, 0, 0], [0, 178742093598241949212694, -2904753042619567499757, 157001992716259099500, 0, 0], [20018061324328330066512252, 0, 0, 0, -812238647542755290200, 26581687276500968370], [0, 340948050117592988964472, 12013996036717249754244, -79335337632305558300, 0, 0], [35681080236038775864304902, 0, 0, 0, 951723674004299909040, -263153052237410876052], [-16776495988588942215783840, 0, 0, 0, -3112624973002901601504, 234742299587815105284], [0, -135213036510101175058762, 13543322671513513727493, 229587473410361359775, 0, 0], [0, -263823452041436303185040, 5172825116435691537516, -388123603757453738190, 0, 0], [0, -50395836398250060929974, 3654265770923910211287, 202132254689225195379, 0, 0], [-3357502460784666671822830, 0, 0, 0, 686783789107194851712, -267204905803045768675], [0, -73530551990385022926372, -26652341838237535458564, -198591996003395707533, 0, 0], [0, -70803271967284536577154, 34328290723621906725, 365710469392927182105, 0, 0], [-7781905830066905276622020, 0, 0, 0, 637175633280591179688, -147223937428213212398], [0, -168755484545238262192152, 23868946084356422166264, 30677163249115124010, 0, 0], [0, -465988364432713636080140, -10196456541718196129328, 62234616215734546479, 0, 0], [0, -168527248712362812404962, 25518407265833516654571, 108220544336766404538, 0, 0], [45591865251454919716978590, 0, 0, 0, -418934227618100151576, 225138987224128769265], [22127281292195850980114052, 0, 0, 0, 419819970754886098520, -167150259635227606086], [-135828748164900738665125000, 0, 0, 0, -197004728232878050320, -277920137905606670824]]
